#
# spec file for package qt-creator
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 17.0.0
%define short_version 17.0
%define tar_name qt-creator-opensource-src
%define tar_suffix %{nil}
#
%global flavor qt6%{nil}
%if "%{flavor}" == ""
%define pkgname_prefix qt
ExclusiveArch:  do_not_build
%endif
%if "%{flavor}" == "qt6"
  %define qt6 1
  %define pkgname_prefix qt6
  %define qt_min_version 6.5.3
  %define qtc_docdir %{_qt6_docdir}
%endif
#
%global libexecdirname libexec
%if "%{_libexecdir}" == "%{_prefix}/lib"
%global libexecdirname lib
%endif

# Private QML imports
%global __requires_exclude qt6qmlimport\\((AssetsLibraryBackend|BackendApi|CameraGeometry|CollectionDetails|CollectionEditor|CollectionEditorBackend|ConnectionsEditorEditorBackend|content|ContentLibraryBackend|DataModels|DesignSystemBackend|DesignSystemControls|DeviceManagerControls|EffectComposer.*|EffectMakerBackend|ExampleCheckout|GridGeometry|HelperWidgets|ItemLibraryBackend|LandingPage.*|LightUtils|LineGeometry|MaterialBrowserBackend|MaterialToolBarAction|ModelModules|MouseArea3D|NewProjectDialog|OutputPane|projectmodel|ProjectType|PropertyToolBarAction|QmlDesigner.*|QtQuickDesignerColorPalette|QtQuickDesignerTheme|ScriptEditor.*|ScriptsEditor.*|SelectionBoxGeometry|StatesEditor.*|StudioControls|StudioFonts|StudioHelpers|StudioQuickUtils|StudioTheme|StudioWindowManager|TableModules|TextureToolBarAction|ToolBar|UiTour|usagestatistics|WebFetcher|WelcomeScreen).*

# Has mocks for quite a few components, which are only pulled in when actually used
%global __requires_exclude_from %{_datadir}/qtcreator/qml/qmlpuppet/

%bcond_without docs

Name:           %{pkgname_prefix}-creator
Version:        17.0.0
Release:        1.1
Summary:        Integrated Development Environment targeting Qt apps
# src/plugins/cmakeprojectmanager/configmodelitemdelegate.* -> LGPL-2.1-only OR LGPL-3.0-only
# src/shared/qbs is not built
# src/plugins/imageviewer/imageview.cpp, src/plugins/vcsbase/wizard/vcsconfigurationpage.cpp -> BSD-3-Clause
# src/plugins/emacskeys/* -> GPL-3.0-only
# many files are dual licensed 'LGPL-3.0-only or (GPL-2.0-or-later OR GPL-3.0-or-later + KDE Free Qt Foundation option)', we'll use LGPL-3.0-only for these files
License:        BSD-3-Clause AND GPL-3.0-only AND GPL-3.0-with-Qt-Company-Qt-exception-1.1 AND (LGPL-2.1-only OR LGPL-3.0-only) AND LGPL-3.0-only
URL:            https://www.qt.io/product/development-tools
Source:         https://download.qt.io/official_releases/qtcreator/%{short_version}/%{real_version}%{tar_suffix}/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source1:        qt-creator-rpmlintrc
# Patches 0-10 are upstream changes
# Patches 11-20 are openSUSE changes
Patch11:        fix-application-output.patch
Patch12:        0001-Disable-some-plugins.patch
##
BuildRequires:  cmake
# clang-devel in Leap 15 points to clang7...
%if 0%{?suse_version} == 1500
# Use the same version as qt6-tools
BuildRequires:  clang19-devel
BuildRequires:  llvm19-devel
%else
BuildRequires:  clang-devel >= 10.0
BuildRequires:  llvm-devel
%endif
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  python3 >= 3.5
BuildRequires:  cmake(yaml-cpp)
BuildRequires:  pkgconfig(libdw)
BuildRequires:  pkgconfig(libelf)
BuildRequires:  pkgconfig(libzstd)
%if 0%{?qt6}
BuildRequires:  qt6-core-private-devel >= %{qt_min_version}
BuildRequires:  qt6-gui-private-devel >= %{qt_min_version}
BuildRequires:  qt6-qml-private-devel >= %{qt_min_version}
BuildRequires:  qt6-qmlcompiler-private-devel >= %{qt_min_version}
BuildRequires:  qt6-qmldom-devel-static >= %{qt_min_version}
BuildRequires:  qt6-qt5compat-devel >= %{qt_min_version}
BuildRequires:  qt6-quick-private-devel >= %{qt_min_version}
BuildRequires:  qt6-quick3d-private-devel >= %{qt_min_version}
BuildRequires:  qt6-quick3dassetimport-private-devel >= %{qt_min_version}
BuildRequires:  qt6-quick3dassetutils-private-devel >= %{qt_min_version}
BuildRequires:  qt6-quick3dparticles-private-devel >= %{qt_min_version}
BuildRequires:  qt6-tools-qdoc >= %{qt_min_version}
BuildRequires:  cmake(Qt6Charts) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Concurrent) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Core) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Core5Compat) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Designer) >= %{qt_min_version}
BuildRequires:  cmake(Qt6DesignerComponentsPrivate) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Help) >= %{qt_min_version}
BuildRequires:  cmake(Qt6LinguistTools) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Network) >= %{qt_min_version}
BuildRequires:  cmake(Qt6PrintSupport) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Quick3D) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Quick3DAssetImport) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Quick3DAssetUtils) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Quick3DParticles) >= %{qt_min_version}
BuildRequires:  cmake(Qt6QuickWidgets) >= %{qt_min_version}
BuildRequires:  cmake(Qt6SerialPort) >= %{qt_min_version}
BuildRequires:  cmake(Qt6ShaderTools) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Sql) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Svg) >= %{qt_min_version}
BuildRequires:  cmake(Qt6SvgWidgets) >= %{qt_min_version}
# Needed by the extensionsystem lib
BuildRequires:  cmake(Qt6Test) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Tools) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt_min_version}
BuildRequires:  cmake(Qt6Xml) >= %{qt_min_version}
BuildRequires:  pkgconfig(libsecret-1)
# Explicitly require qt6-sql-sqlite (needed by help system).
Requires:       qt6-sql-sqlite
Recommends:     cmake-doc-qhelp
Recommends:     qt6-base-devel
Recommends:     qt6-base-docs-qch
# Shows examples when starting qt-creator (related: boo#1218403)
Recommends:     qt6-base-examples
Recommends:     qt6-declarative-devel
Recommends:     qt6-declarative-docs-qch
Recommends:     qt6-declarative-examples
Recommends:     qt6-translations
# Generic name recommended by the KDE pattern
Provides:       qt-creator = %{version}
Provides:       libqt5-creator = %{version}
Obsoletes:      libqt5-creator < %{version}
Provides:       qt5-creator = %{version}
Obsoletes:      qt5-creator < %{version}
%endif
Requires:       hicolor-icon-theme

%description
Qt Creator is an integrated development environment (IDE) designed to
facilitate development with the Qt application framework.

%package plugin-devel
Summary:        Qt Creator Plugin Development Files
Requires:       %{pkgname_prefix}-creator = %{version}
%if 0%{?qt6}
Requires:       qt6-base-devel >= %{qt_min_version}
Provides:       libqt5-creator-plugin-devel = %{version}
Provides:       qt5-creator-plugin-devel = %{version}
Obsoletes:      libqt5-creator-plugin-devel < %{version}
Obsoletes:      qt5-creator-plugin-devel < %{version}
%endif

%description plugin-devel
This package contains all files from the Qt Creator source directory
(aka QTC_SOURCE) necessary to compile plugins.

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

# Don't build qbs, we already have a package
rm -r src/shared/qbs

%build
%define _lto_cflags %{nil}

# - qtc wants relative paths for CMAKE_INSTALL_LIB{,EXEC}DIR
# - https://bugreports.qt.io/browse/QTCREATORBUG-24357 suggests disabling
#   the clangpchmanagerbackend and clangrefactoringbackend builds
%if 0%{?qt6}
%cmake_qt6 \
%endif
  -DCMAKE_INSTALL_LIBDIR:STRING=%{_lib} \
  -DCMAKE_INSTALL_LIBEXECDIR:STRING=%{libexecdirname} \
  -DCLANGTOOLING_LINK_CLANG_DYLIB:BOOL=TRUE \
  -DBUILD_WITH_PCH:BOOL=FALSE \
  -DWITH_DOCS:BOOL=TRUE \
  -DBUILD_TESTING:BOOL=FALSE \
  -DQTC_SEPARATE_DEBUG_INFO:BOOL=FALSE \
  -DBUILD_LIBRARY_QLITEHTML:BOOL=TRUE \
  -DBUILD_HELPVIEWERBACKEND_QTWEBENGINE:BOOL=FALSE

%if 0%{?qt6}
%{qt6_build}
%if %{with docs}
%{qt6_build_docs}
%endif
%endif

%install
%if 0%{?qt6}
%{qt6_install}
%endif

# Install files needed to develop qtcreator plugins.
DESTDIR=%{buildroot} cmake --install build --component Devel

# The upstream scripts should not be needed for plugins development
rm -r %{buildroot}%{_datadir}/qtcreator/scripts

# Already packaged
rm %{buildroot}%{_datadir}/qtcreator/{HACKING,LICENSE.GPL3-EXCEPT,README.md}

# Broken and useless for most users
rm %{buildroot}%{_bindir}/qtcreator.sh

%if %{with docs}
# Install the doc files
mkdir -p %{buildroot}%{qtc_docdir}
pushd build
cp share/doc/qtcreator/qtcreator.qch %{buildroot}%{qtc_docdir}/
popd

mkdir -p %{buildroot}%{qtc_docdir}/qtcreator
cp -a doc/qtcreator/* %{buildroot}%{qtc_docdir}/qtcreator/
%endif

# Source Code Pro is packaged independently
rm -r %{buildroot}%{_datadir}/qtcreator/fonts

rm -r %{buildroot}%{_datadir}/qtcreator/debugger-with-python2

%ldconfig_scriptlets

%files
%license LICENSES/*
%doc README.md HACKING
%dir %{_datadir}/qtcreator
%dir %{_libdir}/qtcreator
%dir %{_libexecdir}/qtcreator
%{_bindir}/qtcreator
%{_datadir}/applications/org.qt-project.qtcreator.desktop
%{_datadir}/icons/hicolor/*/apps/QtProject-qtcreator.png
%{_datadir}/metainfo/org.qt-project.qtcreator.appdata.xml
%{_datadir}/qtcreator/android/
%{_datadir}/qtcreator/changelog/
%{_datadir}/qtcreator/cplusplus/
%{_datadir}/qtcreator/debugger/
%{_datadir}/qtcreator/externaltools/
# Upstream build system is a mess and doesn't allow using the KF6 SyntaxHighlighting framework
%{_datadir}/qtcreator/generic-highlighter/
%{_datadir}/qtcreator/glsl/
%{_datadir}/qtcreator/indexer_preincludes/
%{_datadir}/qtcreator/jsonschemas/
%{_datadir}/qtcreator/lua-lupdate/
%{_datadir}/qtcreator/lua-plugins/
%{_datadir}/qtcreator/modeleditor/
%{_datadir}/qtcreator/package-manager/
%{_datadir}/qtcreator/qml-type-descriptions/
%{_datadir}/qtcreator/qmldesigner/
%{_datadir}/qtcreator/qmlicons/
%{_datadir}/qtcreator/schemes/
%{_datadir}/qtcreator/snippets/
%{_datadir}/qtcreator/styles/
%{_datadir}/qtcreator/templates/
%{_datadir}/qtcreator/themes/
%{_datadir}/qtcreator/translations/
%{_libdir}/qtcreator/*.so.*
%{_libdir}/qtcreator/plugins/
%{_libexecdir}/qtcreator/buildoutputparser
%{_libexecdir}/qtcreator/cpaster
%{_libexecdir}/qtcreator/perf2text
%{_libexecdir}/qtcreator/perfparser
%{_libexecdir}/qtcreator/qmlpuppet*
%{_libexecdir}/qtcreator/qtc-askpass
%{_libexecdir}/qtcreator/qtcreator_process_stub
%{_libexecdir}/qtcreator/qtpromaker
%{_libexecdir}/qtcreator/sdktool
%if %{with docs}
%dir %{qtc_docdir}
%{qtc_docdir}/qtcreator.qch
%{qtc_docdir}/qtcreator/
%endif

%files plugin-devel
%{_includedir}/qtcreator/
%{_libdir}/cmake/QtCreator/
%{_libdir}/qtcreator/*.a
%{_libdir}/qtcreator/*.so
%{_libdir}/qtcreator/objects-*/

%changelog
* Thu Jun 19 2025 Christophe Marin <christophe@krop.fr>
- Update to 17.0.0
  https://www.qt.io/blog/qt-creator-17-released
- Drop patch, merged upstream:
  * 0001-Debugger-Pass-unsigned-int-instead-of-size_t-to-ioct.patch
* Thu Jun 12 2025 Jiri Slaby <jslaby@suse.cz>
- add 0001-Debugger-Pass-unsigned-int-instead-of-size_t-to-ioct.patch
  (QTCREATORBUG-33049)
* Wed May 14 2025 Christophe Marin <christophe@krop.fr>
- Update to 16.0.2
  https://www.qt.io/blog/qt-creator-16.0.2-released
* Fri Apr 11 2025 Christophe Marin <christophe@krop.fr>
- Update to 16.0.1
  https://www.qt.io/blog/qt-creator-16.0.1-released
* Thu Apr  3 2025 Christophe Marin <christophe@krop.fr>
- Update build constraints
* Thu Mar 13 2025 Christophe Marin <christophe@krop.fr>
- Update to 16.0.0
  * https://www.qt.io/blog/qt-creator-16-released
- Rebase patches
* Mon Feb 24 2025 Christophe Marin <christophe@krop.fr>
- Use LLVM 19 on Leap 15 to avoid potential runtime issues
* Thu Jan 23 2025 Christophe Marin <christophe@krop.fr>
- Update to 15.0.1:
  https://www.qt.io/blog/qt-creator-15.0.1-released
- Drop patch:
  * 0001-Revert-Autotools-Make-the-BuildSystem-per-BuildConfi.patch
* Mon Jan 13 2025 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to avoid regression in 15.0.0 (QTCREATORBUG-32305):
  * 0001-Revert-Autotools-Make-the-BuildSystem-per-BuildConfi.patch
* Mon Dec  2 2024 Christophe Marin <christophe@krop.fr>
- Update to 15.0.0
  * https://www.qt.io/blog/qt-creator-15-released
* Tue Oct  1 2024 Christophe Marin <christophe@krop.fr>
- Update to 14.0.2
  * https://www.qt.io/blog/qt-creator-14.0.2-released
* Wed Aug  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 14.0.1:
  * https://www.qt.io/blog/qt-creator-14.0.1-released
* Thu Jul 25 2024 Christophe Marin <christophe@krop.fr>
- Update to 14.0.0
  https://www.qt.io/blog/qt-creator-14-released
- Rebase patches
* Fri Jun  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 13.0.2
  https://www.qt.io/blog/qt-creator-13.0.2-released
  * Fixed that the -client option could start a new Qt Creator
    instance instead of using a running one
  * Fixed that closing files with the tool button didn't add an
    entry to the navigation history
  * Fixed that Use Qt module name in #include-directive used Qt 4
    module names
  * Adapted to changes in the Copilot neovim plugin
  * CMake: Fixed the environment macro expansion for Presets
  * Meson: Fixed a crash when selecting kits
  * Terminal: Fixed the handling of environment variables with an
    equal sign = in the value
  * Git: Fixed a crash in Instant Blame when reloading externally
    modified files
* Wed May  8 2024 Christophe Marin <christophe@krop.fr>
- Update to 13.0.1
  * https://www.qt.io/blog/qt-creator-13.0.1-released
* Thu Apr  4 2024 Christophe Marin <christophe@krop.fr>
- Update to 13.0.0
  * https://www.qt.io/blog/qt-creator-13-released
* Fri Mar 15 2024 Christophe Marin <christophe@krop.fr>
- Update to 13.0.0~rc1:
  * https://www.qt.io/blog/qt-creator-13-rc-released
* Sat Mar  9 2024 Christophe Marin <christophe@krop.fr>
- Make qt6-creator provide 'qt-creator' for the KDE patterns
* Wed Feb  7 2024 Christophe Marin <christophe@krop.fr>
- Update to 12.0.2. Bugfix release:
  * https://www.qt.io/blog/qt-creator-12.0.2-released
- Drop patch, merged upstream:
  * 0001-Register-AutotoolsProject-as-handler-for-Makefiles-a.patch
* Mon Jan 22 2024 Fabian Vogt <fvogt@suse.com>
- Add patch to fix opening Makefile projects:
  * 0001-Register-AutotoolsProject-as-handler-for-Makefiles-a.patch
* Wed Dec 13 2023 Christophe Marin <christophe@krop.fr>
- Update to 12.0.1. Bugfix release:
  * https://www.qt.io/blog/qt-creator-12.0.1-released
* Thu Nov 23 2023 Christophe Marin <christophe@krop.fr>
- Update to 12.0.0:
  * https://www.qt.io/blog/qt-creator-12-released
  New features:
  * Integrated compiler explorer
  * CMake debugging and profiling
  * Screen recording
* Thu Nov 23 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add more exclusions for private imports (boo#1217421)
* Thu Sep 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 11.0.3:
  * https://www.qt.io/blog/qt-creator-11.0.3-released
- Drop patch, merged upstream:
  * 0001-ClangTools-Add-support-for-yaml-cpp-0.8.patch
* Fri Aug 25 2023 Christophe Marin <christophe@krop.fr>
- Add upstream change to fix detection of yaml-cpp 0.8:
  * 0001-ClangTools-Add-support-for-yaml-cpp-0.8.patch
* Tue Aug 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 11.0.2
  https://www.qt.io/blog/qt-creator-11.0.2-released
* Mon Aug  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 11.0.1:
  https://www.qt.io/blog/qt-creator-11.0.1-released
* Thu Jul 20 2023 Christophe Marin <christophe@krop.fr>
- Use a mirror to download sources for all Qt packages. Upstream
  servers are very slow since a couple weeks.
- Update to 11.0.0:
  https://www.qt.io/blog/qt-creator-11-released
* Thu Jun 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 10.0.2:
  * https://www.qt.io/blog/qt-creator-10.0.2-released
- Don't build docs on Leap 15.4, llvm crashes
- Drop patch, merged upstream:
  * 0001-QmlDesigner-Fix-puppet-build-after-quick3d-private-A.patch
* Fri May 26 2023 Christophe Marin <christophe@krop.fr>
- Add patch to fix build failure with QtQuick3d 6.5.1:
  * 0001-QmlDesigner-Fix-puppet-build-after-quick3d-private-A.patch
* Sun May  7 2023 Christophe Marin <christophe@krop.fr>
- Update to 10.0.1. Bugfix release:
  * https://www.qt.io/blog/qt-creator-10.0.1-released
* Thu Mar 30 2023 Christophe Marin <christophe@krop.fr>
- Update to 10.0.0. New feature release:
  * https://www.qt.io/blog/qt-creator-10-released
* Wed Feb 22 2023 Christophe Marin <christophe@krop.fr>
- Update to 9.0.2. Bugfix release:
  * https://www.qt.io/blog/qt-creator-9.0.2-released
* Wed Jan 18 2023 Andreas Schwab <schwab@suse.de>
- Update constraints for riscv64
* Wed Jan 11 2023 Christophe Marin <christophe@krop.fr>
- Use llvm13 on Leap 15.4 and llvm15 on 15.5
* Mon Jan  2 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Update fix-application-output.patch to work with current versions
* Fri Dec 16 2022 Christophe Marin <christophe@krop.fr>
- Update to 9.0.1. Bugfix release:
  * https://www.qt.io/blog/qt-creator-9.0.1-released
- Rebase fix-application-output.patch
* Thu Nov 24 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 9.0.0. Note: Qt Creator no longer builds with Qt5.
  * https://www.qt.io/blog/qt-creator-9-released
  * Experimental Squish Support
  * Dark themes support for the help menu
  * Option for visualizing the indentation in the document
  * You can now use a single Clangd instance for a whole session
    (vs. one instance / project)
  * CMake: added support for configure and build presets
* Sat Oct 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 8.0.2. Bugfix release:
  * https://www.qt.io/blog/qt-creator-8.0.2-released
* Thu Aug 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 8.0.1:
  * https://www.qt.io/blog/qt-creator-8.0.1-released-1
  performance improvements and bug fixes for issues with:
  - running and debugging bare metal applications
  - the code model
  - rebooting Boot2Qt devices
  - various other things
- Drop 0001-Fixes-license-header.patch. Merged upstream
* Fri Jul 22 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 8.0.0:
  * https://www.qt.io/blog/qt-creator-8-released
  Note that this is the last release that can be built using Qt 5.
- Add upstream change to fix license issues:
  * 0001-Fixes-license-header.patch
* Tue Jul 19 2022 Christophe Giboudeaux <christophe@krop.fr>
- Remove the qmldesigner data folder when building qt-creator
  with Qt5. The plugin is only available with the Qt 6 variant.
* Fri Jul  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 8.0.0-rc1:
  * https://www.qt.io/blog/qt-creator-8-rc-released
* Wed Jun 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 8.0.0-beta2:
  * https://www.qt.io/blog/qt-creator-8-beta2-released
- Drop patch, fixed upstream:
  * 0001-Correctly-include-KSyntaxHighlighting-headers.patch
* Mon May 30 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.0.2. Bugfix release:
  * https://www.qt.io/blog/qt-creator-7.0.2-released
- Add patch to fix build with recent KSyntaxHighlighting releases:
  * 0001-Correctly-include-KSyntaxHighlighting-headers.patch
* Sun May  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Don't let the %%cmake macro ignore the install rpath (boo#1198281)
* Wed Apr 27 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.0.1. Bugfix release:
  * https://www.qt.io/blog/qt-creator-7.0.1-released
- Remove obsolete version check
* Mon Apr 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Fix the plugin-devel package (boo#1197978)
  To create qt-creator plugins, some files not installed by default
  are required.
* Thu Mar 24 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.0.0
  * https://www.qt.io/blog/qt-creator-7-released
* Fri Mar 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 7.0.0~rc1:
  * https://www.qt.io/blog/qt-creator-7-rc-released
- Drop c7deacf.diff. Merged upstream
- Rebase fix-application-output.patch
* Fri Feb  4 2022 Matthias Fehring <buschmann23@opensuse.org>
- Explicitly require SQLite plugin for QtSql that is needed by the
  help system.
* Thu Jan 20 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.2
  https://code.qt.io/cgit/qt-creator/qt-creator.git/plain/dist/changes-6.0.2.md
  * Fixed crash in process launcher
  * Fixed that `Select All` scrolled to bottom
  * Fixed copying with block selection
  * Fixed working directory for `REPL`
  * Fixed missing options in property editor
  * Fixed that closing application in `Application Output` pane
    killed process even if `Keep Running` was selected
  * Fixed filtering in target setup page
  * Fixed crash when switching screen configuration
- Add patch to fix the 32bit builds:
  * c7deacf.diff
* Wed Dec 22 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.1
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-6.0.1.md
* Thu Dec  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0
  https://www.qt.io/blog/qt-creator-6-released
- Drop the SUSE_IGNORED_RPATHS workaround now that the binutils
  bug is fixed.
* Fri Oct 29 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0-beta2
  https://www.qt.io/blog/qt-creator-6-beta2-released
* Thu Oct 14 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.0.0~beta1:
  * https://www.qt.io/blog/qt-creator-6-beta-released
- Rename libqt5-creator to qt5-creator
- Add a qt6 flavor
- Rebase fix-application-output.patch
* Mon Oct 11 2021 Christophe Giboudeaux <christophe@krop.fr>
- Unset SUSE_IGNORED_RPATHS to avoid a build failure caused by one
  of the binutils patches (boo#1191473)
* Fri Oct  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.0.2
  * Fixed that Qt 5 context help was shown even if Qt 6
    documentation is available
  * Fixed canceling of builds
  * Changed the `File System` special node to be shown only on
    parsing failure
  * Fixed loading of projects without targets
  * Fixed that no targets where shown in added build step
  * Fixed that `ninja` could not be found after changing Qt
    installation location
  * Fixed debugging of terminal applications with GDB < 10
* Wed Sep 15 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.0.1
  * https://www.qt.io/blog/qt-creator-5.0.1-released
* Thu Aug 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.0.0
  * https://www.qt.io/blog/qt-creator-5.0-released
* Thu Aug 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.0.0-rc1
- Rebase 0001-Disable-some-plugins.patch
* Mon Jul 19 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.15.2
  * https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.15.2.md
* Thu Jun 10 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.15.1:
  * https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.15.1.md
* Thu May 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.15.0:
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.15.0.md
- Update 0001-Disable-some-plugins.patch
- Rebase fix-application-output.patch
* Mon Mar 22 2021 Christophe Giboudeaux <christophe@krop.fr>
- Work around boo#1179155 and explicitly require clang11
  for Leap 15.3.
* Mon Mar 22 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.14.2
  * Fixed installation location of desktop and appstream files
  * Fixed crash with `Previous/Next Open Document in History`
  * Re-added generic highlighting for Autoconf files
  * LLDB:  Fixed performance issue
- Drop 0001-Fix-a-link-error-when-building-the-qmldesigner-plugi.patch
  Merged upstream.
* Fri Feb 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.14.1
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.14.1.md
- Drop patches:
  * cmake-build-use-gnuinstalldirs.patch
  * 0001-Don-t-rely-on-clang-include-and-binary-copies.patch
  * 0001-cmake-build-Don-t-install-highlighting-files-when-us.patch
  * 0001-Fix-compilation-of-ClangFormat-plugin-against-LLVM-w.patch
- Rebase 0001-Disable-some-plugins.patch
* Sun Jan 31 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add compatibility with qml-autoreqprov
- Don't recommend obsolete libqt5-qtquick1-devel
* Tue Jan 19 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Add patch to use GNUInstallDirs instead of using sed:
  * cmake-build-use-gnuinstalldirs.patch
* Thu Dec 17 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.14.0:
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.14.0.md
- Enable the new CLANGTOOLING_LINK_CLANG_DYLIB option.
- Use %%_libexecdir when possible
- Rebase patches:
  * Update fix-application-output.path
  * 0001-Don-t-rely-on-clang-include-and-binary-copies.patch
  * 0001-Disable-some-plugins.patch
- Drop 0001-Fix-build-with-openSUSE-clang9-package.patch. no
  longer needed.
- Add upstream patches:
  * 0001-cmake-build-Don-t-install-highlighting-files-when-us.patch
  * 0001-Fix-compilation-of-ClangFormat-plugin-against-LLVM-w.patch
- Add patch:
  * 0001-Fix-a-link-error-when-building-the-qmldesigner-plugi.patch
* Mon Nov 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.13.3
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.13.3.md
* Thu Oct  1 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.13.2
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.13.2.md
- Add patch to avoid relying on non-existent clang file copies (boo#1176888)
  * 0001-Don-t-rely-on-clang-include-and-binary-copies.patch
* Thu Sep 17 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.13.1
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.13.1.md
* Thu Aug 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.13.0
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.13.0.md
* Thu Aug  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.13.0-beta2
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.13.0.md
- Drop 0001-Fix-build-with-yaml-cpp-installed-and-CMake-3.11.patch
  Merged upstream
* Tue Jul 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.13.0-beta1
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.13.0.md
- Use CMake for building qt-creator
- Update 0001-Fix-build-with-openSUSE-clang9-package.patch
- Add 0001-Disable-some-plugins.patch to disable building of three plugins:
  * updateinfo works when using the Qt installer
  * clangformat requires a Clang patch which was never accepted
    upstream
  * qlitehtml has installation issues.
- Add patch to fix build with CMake < 3.11:
  * 0001-Fix-build-with-yaml-cpp-installed-and-CMake-3.11.patch
* Fri Jun  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Disable LTO. This is causing a build error.
* Wed Jun  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.12.2
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.12.2.md
  * Fixed line and column support for opening files with Locator
  * Fixed crash with QML Preview
  * Fixed issue with Clazy 1.6
  * Fixed persistence of diagnostics configurations
  * Fixed persistence of license template setting
* Wed May 20 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.12.1.
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.12.1.md?h=4.12
  * Fixed crash when changing font settings
  * Fixed availability of `Link with Qt` information on startup
  * Fixed crash when loading settings from Qt Creator < 4.11
  * Fixed semantic highlighting
  * Fixed wrong symbol highlighting
  * Fixed warning for `palette` property
- Drop android-guard-against-kits-without-qt-version.patch.
  Fixed upstream.
- Rebase 0001-Fix-build-with-openSUSE-clang9-package.patch
* Tue May  5 2020 Fabian Vogt <fvogt@suse.com>
- Add patch to fix crash on startup (boo#1170872, QTCREATORBUG-23963):
  * android-guard-against-kits-without-qt-version.patch
* Thu Apr 30 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Set QBS_INSTALL_DIR to also build the qbsprojectmanager plugin
* Thu Apr 23 2020 Fabian Vogt <fvogt@suse.com>
- Update to 4.12.0:
  * Added browser for Marketplace items to Welcome mode
  * Added option to register documentation only for highest Qt version, and made that default
  * Updated QML parser to Qt 5.15
  * Changed to use separate Qbs executable instead of direcly linking to Qbs
  * And much more. Full changelog on
    https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.12.0.md?h=4.12
- Dropped unneeded exporting of LLVM_INSTALL_DIR
- Don't build the bundled Qbs anymore
* Wed Apr  1 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.11.2.
  * Improved performance of highlighting
  * Fixed that `Rewrap Paragraph` split on non-breaking space
  * Fixed freeze with block selection
  * Fixed high CPU usage after scrolling horizontally
  * Fixed scroll position after splitting if text cursor is not visible
  * Fixed position of markers in scrollbar for long documents
  * Fixed warnings in files generated by Python file wizard
  * Fixed issue with server restart after server crash
  * Fixed wrong default project for adding files via wizards
  * Fixed startup if `_NT_DEBUGGER_EXTENSION_PATH` is set
  * Fixed debugging of Qt Quick tests
* Fri Feb 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Raise the disk space and set a minimum memory in _constraints.
* Thu Feb  6 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.11.1. Check
  https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.11.1.md?h=4.11
  for the complete changelog.
* Thu Dec 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.11.0.
  * Check https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.11.0.md?h=4.11
    for the changelog.
* Wed Dec  4 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.11-rc1.
  * Check https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.11.0.md?h=4.11
    for the changelog.
- Add 0001-Fix-build-with-openSUSE-clang9-package.patch to work around
  https://bugreports.qt.io/browse/QTCREATORBUG-23172.
* Tue Nov  5 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.10.2
  * General
  - Added experimental SerialTerminal plugin to prebuilt binaries
  * CMake
  - Fixed issue with deployment to remote Linux devices (QTCREATORBUG-21235)
  * Qbs
  - Fixed executable path in run configuration when custom installation directory
    is specified (QTCREATORBUG-23039)
  * Debugging
  - Fixed crash when logging output (QTCREATORBUG-22733)
  - Fixed crash when removing previously dragged breakpoint (QTCREATORBUG-23107)
  - Fixed highlighting of watch item when value changes
  * GTest
  - Fixed `Run Under Cursor` (QTCREATORBUG-23068)
  * Boost
  - Fixed handling of parameterized tests
* Tue Oct 15 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.10.1
  * Editing
  - Fixed file saving with some text encodings
  - Fixed `Preserve case` in advanced search and replace (QTCREATORBUG-19696)
  - Fixed crash when changing editor font (QTCREATORBUG-22933)
  * Help
  - Fixed that text moved around when resizing and zooming (QTCREATORBUG-4756)
  * All Projects
  - Fixed `Qt Creator Plugin` wizard (QTCREATORBUG-22945)
  * Debugging
  - Fixed more layout restoration issues (QTCREATORBUG-22286, QTCREATORBUG-22415, QTCREATORBUG-22938)
  * LLDB
  - Fixed wrong empty command line argument when debugging (QTCREATORBUG-22975)
  * Qt Quick Designer
  - Removed transformations from list of unsupported types
  - Fixed update of animation curve editor
* Thu Sep 19 2019 Herbert Graeber <herbert@graeber-clan.de>
- Add new pri file to plugin-devel subpackage
* Mon Sep  9 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Cleanup spec file, remove any conditionals for Leap 42.x and older.
- Use correct Requires for Clang header files, located in libclang
  package since Clang 6.
* Thu Sep  5 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 4.10.0 final:
  * No changelog available
* Wed Sep  4 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add libqt5-qttools-doc BuildRequires to fix build after the
  recent dependency changes in libqt5-qttools
* Fri Aug  2 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 4.10.0 RC1:
  * Language Server Client is now longer experimental
  * For an overview of new features in the 4.10 series, see
    https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.10.0.md?h=4.10
- Drop fix-build-isystem.patch. Merged upstream.
* Sat Jun 29 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 4.9.2:
  * General
    + Fixed display of shortcuts in `Keyboard` preferences (QTCREATORBUG-22333)
  * Editing
    + Fixed disabled editor close button in Design mode (QTCREATORBUG-22553)
  * Syntax Highlighting
    + Fixed highlighting issue while editing (QTCREATORBUG-22290)
  * All Projects
    + Fixed saving state of `Hide Empty Directories`
    + Fixed crash that could happen after project parsing failed
  * C++ Support
    + Fixed expansion of `%%DATE%%` in license templates (QTCREATORBUG-22440)
  * Qt Quick Designer
    + Fixed crash on malformed QML (QDS-778)
* Wed Jun  5 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the 'License:' tag.
* Fri May 31 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 4.9.1:
  * Editing
    + Fixed folding for generic highlighter (QTCREATORBUG-22346)
  * QMake Projects
    + Fixed unnecessary reparsing on file save (QTCREATORBUG-22361)
    + Fixed code model for generated files when specified in `.pri` file
    (QTCREATORBUG-22395)
  * CMake Projects
    + Fixed deployment with `QtCreatorDeployment.txt` (QTCREATORBUG-22184)
    + Fixed that configuration UI was disabled after configuration error
  * Qbs Projects
    + Fixed crash when editing environment variables (QTCREATORBUG-22386)
    + Fixed handling of `cpp.minimum*Version` (QTCREATORBUG-22355)
  * Debugging
    + Fixed ambiguity of `F10` shortcut (QTCREATORBUG-22330)
    + CDB
  - Fixed `Start and Break on Main` (QTCREATORBUG-22263)
  * Test Integration
    + Fixed `Uncheck All`
  * Android
    + Fixed AVD creation for Google Play images
  * Remote Linux
    + Fixed crash when running `Custom Executable` on remote Linux target
    from Windows host (QTCREATORBUG-22414)
    + Fixed SSH connection sharing on macOS (QTCREATORBUG-21748)
    + Deployment via SFTP
  - Fixed `Unexpected stat output for remote file` (QTCREATORBUG-22041)
  - Fixed deployment of symbolic links (QTCREATORBUG-22307)
    + Deployment via rsync
  - Fixed compatibility issue with command line parameters
    (QTCREATORBUG-22352)
* Mon Apr 15 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 4.9.0:
  * New features for the language server protocol implementation
  * Generic highlighter now based on KSyntaxHighlighting
  * Improved UI for the Clang analyzer tools
  * QML parser supports Qt 5.12 features now
  * New perf plugin
  * New plugin for generic deployment methods
  * Many bug fixes, as usual
  * Full changelog available at
    https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.9.0.md?h=4.9
* Sat Mar  2 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 4.8.2:
  * General
    + Fixed UI for choosing executable for external tools (QTCREATORBUG-21937)
  * Editing
    + Fixed highlighting of search results of regular expression search
    (QTCREATORBUG-21887)
  * Autotools Projects
    + Fixed that includes, defines and flags of `SUBDIRS` were ignored
    (QTCREATORBUG-21618)
  * C++ Support
    + Fixed crash when expanding macros (QTCREATORBUG-21642)
    + Fixed crash in preprocessor (QTCREATORBUG-21981)
    + Fixed infinite loop when resolving pointer types (QTCREATORBUG-22010)
    + Fixed cursor position after completion of functions without arguments
    (QTCREATORBUG-21841)
  * QML Support
    + Fixed auto-insertion of single quotes
  * Debugging
    + GDB
  - Fixed detaching from process (QTCREATORBUG-21908)
    + LLDB
  - Fixed stopping at some breakpoints with newer LLDB (QTCREATORBUG-21615)
  - Fixed `Attach to Process` and `Run in Terminal` with newer LLDB
    + CDB
  - Fixed display of `QDateTime` (QTCREATORBUG-21864)
  * Qt Quick Designer
    + Added support for more JavaScript functions in `.ui.qml` files
    + Fixed crash with gradients and Qt Quick 5.12 (QDS-472)
  * Test Integration
    + Fixed handling of empty tests
  * Android:
    + Fixed upload of GDB server on some devices (QTCREATORBUG-21317)
    + Fixed crash on exiting debugger (QTCREATORBUG-21684)
* Mon Feb 11 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Enable clangcodemodel for Leap 15.1+ as well
* Mon Feb 11 2019 Fabian Vogt <fabian@ritter-vogt.de>
- Work around QTCREATORBUG-21972 by requiring a specific clang version
* Wed Feb  6 2019 Wolfgang Bauer <wbauer@tmo.at>
- Make use_system_botan conditional, and build without it on Leap
  42.3 to fix build
* Thu Jan 17 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 4.8.1
  * Fix wrong background color being used for some text highlighting items
  * Fix a crash when renaming a file in the file system view
  * Fix various errors occurring when parsing Boost headers
  * Fix various issues arising with the debugger integration
  * blog.qt.io/blog/2019/01/17/qt-creator-4-8-1-released/
* Wed Dec 19 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Set Version correctly
* Thu Dec  6 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 4.8.0 final:
  * http://blog.qt.io/blog/2018/12/06/qt-creator-4-8-0-released/
* Tue Dec  4 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Also set QT_FORCE_STDERR_LOGGING in fix-application-output.patch
* Tue Nov 27 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 4.8.0 RC 1:
  * Even more bugfixes
- Update to 4.8.0 Beta 2:
  * More bugfixes
- Refresh fix-application-output.patch
* Tue Nov 27 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Remove dmgbuild script to avoid dep on python2
- Set use_system_botan properly
* Wed Nov 14 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Don't try to use WebEngine on unsupported architectures
* Sat Oct 13 2018 fabian@ritter-vogt.de
- Update to 4.8.0 Beta 1:
  * Added experimental plugin LanguageClient for supporting the
    language server protocol (QTCREATORBUG-20284)
  * Added experimental plugin CompilationDatabaseProjectManager
    that opens a compilation database for code editing
  * Added experimental plugin ClangFormat that bases
    auto-indentation on Clang Format
  * Added experimental plugin Cppcheck for integration of
    cppcheck diagnostics
  * Added support for multiple simultaneous debugger runs
  * Fixed 'Open Terminal Here' for konsole (QTCREATORBUG-20900)
  * Many other fixes and improvements. Full changelog:
    https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.8.0.md?h=4.8
* Tue Oct  2 2018 Javier Llorente <javier@opensuse.org>
- Update to 4.7.1
  * Fixed that generic highlighting could use unreadable colors
  (QTCREATORBUG-20919)
  * Fixed jumping text cursor when editing custom executable path
  * Fixed C++ version passed to code model (QTCREATORBUG-20909)
  * Fixed include order for Clang headers
  * Fixed that comments could break reformatting (QTCREATORBUG-21036)
  * Fixed remote debugging command line argument (QTCREATORBUG-20928)
  * Fixed environment for `Start and Debug External Application`
  (QTCREATORBUG-20185)
  * Fixed GDB built-in pretty printer handling (QTCREATORBUG-20770)
  * Fixed pretty printing of enums
  * Fixed re-enabling breakpoints (QTCREATORBUG-20795)
  * Fixed `Attach to QML Port` (QTCREATORBUG-20168)
  * Switched SSH support to use Botan 2 (QTCREATORBUG-18802)
- Removed 0001-Build-with-Botan-2.patch (merged upstream) / updated spec
* Sat Sep  1 2018 fabian@ritter-vogt.de
- Use WebEngine instead of WebKit for rendering Help
- Also enable the clang code model for aarch64
- Adjust License tag
- Don't install Adobe Source Code Pro fonts
- Change fix-application-output.patch to only apply to Qt < 5.11
* Thu Jul 26 2018 javier@opensuse.org
- Update to 4.7.0
  * Clang code model is now turned on by default
  * Upgraded Clang code model to Clang 6.0
  * New 'Run Test Under Cursor' action
  * QML support: Updated parser to Qt 5.10, adding support for
  user-defined enums
  * Various bugfixes
  * https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.7.0.md?h=4.7
- Update qt5_version to 5.9.0
* Fri May 25 2018 fabian@ritter-vogt.de
- Don't try to build docs if qdoc not available
* Fri May  4 2018 fabian@ritter-vogt.de
- Update to 4.6.1:
  * Fixes for various crashes and other bugs
  * Introduce Qt 5.11 to wizards
  * Fix 32-bit Android deploymend
  * https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.6.1.md?h=4.6
* Thu Apr 26 2018 herbert@graeber-clan.de
- Fix plugin-devel subpackage
  * Add *.hpp files
  * Add 3rd party license files
* Mon Apr 16 2018 fabian@ritter-vogt.de
- Update to 4.6.0:
  * Clang code model uses clang 5, supporting C++17
  * Quick Designer: Added font and text properties from Qt 5.10
  * Various other improvements
  * Various bugfixes
- Remove patches, now upstream:
  * lldb.diff
* Thu Apr 12 2018 javier@opensuse.org
- Add fix-application-output.patch
  Fixes no application output. Might be fixed on Qt 5.11
* Thu Mar  1 2018 christophe@krop.fr
- Add 0001-Build-with-Botan-2.patch.
  Fixes build with Botan 2 on openSUSE >= 15.0
* Sat Feb  3 2018 wbauer@tmo.at
- Build with gcc7 on Leap 42.3, gcc6 no longer works because of a
  change to the default compiler flags in openSUSE:Leap:42.3:Update
  (boo#1077345)
* Wed Dec 27 2017 jengelh@inai.de
- Ensure neutrality of descriptions.
* Wed Dec 20 2017 fabian@ritter-vogt.de
- Recommend libqt5-qtdoc-qch instead of libqt5-qtdoc
- Remove %%defattr from %%files
- Remove BuildRoot
* Sat Dec  9 2017 christophe@krop.fr
- Update to 4.5.0
  * Added `Edit` > `Advanced` > `Sort Selected Lines`
  * Progress report while parsing projects
  * CMake : new options to handle variables
  * Full changelog available on
    https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.5.0.md?h=4.5
  * Require the exact QtDesignerComponents library.
* Sun Sep 24 2017 jaime.marquinez.ferrandiz@fastmail.net
- Fix building of the QmlDesigner plugin by adding libqt5-qtquickcontrols
  BuildReq (and matching runtime Requires)
* Tue Sep  5 2017 fabian@ritter-vogt.de
- Update to 4.4.0
  * Support for inline annotations
  * Animated scrolling
  * Improvements in the default color scheme
  * Cleaned up CMake project tree
  * Full changelog available on
    https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.4.0.md?h=4.4
- Remove patches, now upstream:
  * disable_failing_cxxflags.diff
- Add patch to fix build:
  * fix-build-isystem.patch (QTCREATORBUG-18848)
* Sat Jul  1 2017 fabian@ritter-vogt.de
- Update to 4.3.1
  * Fixes for crashes and other annoyances
  * Changelog available on
    https://code.qt.io/cgit/qt-creator/qt-creator.git/tree/dist/changes-4.3.1.md?h=4.3
* Wed May 24 2017 fabian@ritter-vogt.de
- Update to 4.3.0
  * For more details see:
    https://blog.qt.io/blog/2017/05/24/qt-creator-4-3-0-released/
* Wed May 10 2017 fabian@ritter-vogt.de
- Update to 4.3.0 RC1
  * For more details see:
    http://blog.qt.io/blog/2017/05/09/qt-creator-4-3-rc1-released/
- Remove qtcreator.desktop, file now upstream
- Add patch to fix build failure:
  * disable_failing_cxxflags.diff
* Mon May  1 2017 fabian@ritter-vogt.de
- Update to 4.2.2
  * For more details see:
    https://blog.qt.io/blog/2017/04/21/qt-creator-4-2-2-released/
* Thu Apr 20 2017 fvogt@suse.com
- Remove qbs-path.diff as it needs various other adjustments to
  actually work (boo#962766)
* Mon Mar 13 2017 fabian@ritter-vogt.de
- Update to 4.2.1
  * For more details see:
    https://blog.qt.io/blog/2017/01/23/qt-creator-4-2-1-released/
- Use .desktop file provided by upstream instead of creating our own
* Thu Jan 19 2017 mlin@suse.com
- Increase disk constraints to 10G since sometimes it costs more than 8G. (bsc#1003887)
* Fri Jan 13 2017 fabian@ritter-vogt.de
- Use correct version for llvm-clang-devel dependency
* Wed Dec 28 2016 hrvoje.senjan@gmail.com
- Tell qtcreator's buildsystem to try and build clang plugin only
  with llvm >= 3.9.0
* Fri Dec 16 2016 fabian@ritter-vogt.de
- Update to 4.2.0
  * For more details see:
  https://blog.qt.io/blog/2016/12/14/qt-creator-4-2-released/
* Tue Nov 22 2016 fabian@ritter-vogt.de
- Change license back temporarily. After this is in factory,
  we can resume the wait to get it accepted.
* Thu Aug 25 2016 cgiboudeaux@gmx.com
- Update to 4.1.0
  * For more details see:
  http://blog.qt.io/blog/2016/08/25/qt-creator-4-1-0-released/
- Change the license tag. Digia is no more.
* Sat Jun 11 2016 hrvoje.senjan@gmail.com
- Update to 4.0.1
  * For more details see:
    https://blog.qt.io/blog/2016/06/08/qt-creator-4-0-1-released/
* Mon May 30 2016 alarrosa@suse.com
- Enabled clangcodemodel plugin in SLE12 SP2 since it includes
  a recent enough LLVM version.
* Sat May 28 2016 fvogt@suse.com
- Add Recommends: libqt5-qttranslations
    Without them, bundled translations are ignored
* Wed May 25 2016 herbert@graeber-clan.de
- Add QtConcurrentTools to plugin-devel subpackage
- Add files with QTC_SOURCE- and QTC_BUILD-Envrionment variables to
  to /etc/profiles.d
- Remove test directory form pugin-devel
- Move docs to /usr/share/doc/packages/qt5 like alle other Qt5 docs,
  so that qtcreator.qch will be auto-detected.
- Create a new subpackage that contains the part of the source
  tree, that is relevant for building Qt creator plugins.
* Tue May 17 2016 alarrosa@suse.com
- Added some recommended and suggested development packages so users
  can start using Qt Creator to build new projects right after installing it.
* Tue May 17 2016 alarrosa@suse.com
- Update to 4.0.0
  * For more details see:
    https://blog.qt.io/blog/2016/05/11/qt-creator-4-0-0-released/
* Wed Mar 23 2016 os-dev@jacraig.com
- Also disable the clangcodemodel plugin for 13.2 since, like SLE12, it does
  not have llvm >= 3.6.
* Wed Jan 20 2016 cgiboudeaux@gmx.com
- Replace the 'Conflict: qt-creator' line with Provides/Obsoletes
  entries before dropping qt-creator from openSUSE:Factory.
* Wed Jan 20 2016 cgiboudeaux@gmx.com
- Use the correct libexec path when loading plugins (boo#962650)
* Mon Jan 11 2016 cgiboudeaux@gmx.com
- Update to 3.6.0
  * For more details see:
    https://blog.qt.io/blog/2015/12/15/qt-creator-3-6-0-released
* Fri Dec  4 2015 cgiboudeaux@gmx.com
- Add lldb.diff.
  lldb-* also matches lldb-mi which doesn't recognize the
  - version switch. Fixes boo#957185.
* Thu Oct 29 2015 dvaleev@suse.com
- Add disk constraints.
* Tue Oct 27 2015 rpm@fthiessen.de
- Update to 3.5.1:
  * Fixed that cancel button was ignored when wizards ask about
    overwriting files
  * Fixed crashes with code completion
  * Meruical: Fixed crash when annotating
  * And much more bugfixes, for all changes see:
    http://blog.qt.io/blog/2015/10/15/qt-creator-3-5-1-released/
- Fixed invalid .desktop file
- Made package build on all repositories of the development project
* Wed Sep 30 2015 alarrosa@suse.com
- Disable the clangcodemodel plugin when in SLE12 and Leap, since neither
  of them have llvm >= 3.6, thus removing the requirement.
* Fri Sep  4 2015 alarrosa@suse.com
- BuildRequire llvm-clang-devel minimum version 3.6 since the sources do
* Sat Aug 22 2015 hrvoje.senjan@gmail.com
- Upate to  3.5.0:
  * Increased minimum requirements for compilation of Qt Creator to
    MSVC 2013 and GCC 4.7, and Qt 5.4.0
  * Added variants with native separators to Qt Creator variables
    that represent file paths
  * Changed the way inconsistent enabled states were handled by the
    plugin manager. Disabling plugins is now only a hint; if another
    (enabled) plugin needs it, it is implicitly enabled. Before, the
    other plugin was implicitly disabled.
  * Improved keyboard shortcut settings. Made shortcut input field
    freely editable and added separate `record` button.
  * Added support for `~` as shortcut for user's home directory to
    path input fields
  * Added filtering to About Plugins
  * Added `-load all` and `-noload all` command line options that
    enable and disable all plugins respectively
  * Made `-load` command line option implicitly enable all required
    plugins, and `-noload` disable all plugins requiring the
    disabled plugin. Multiple `-load` and `-noload` options are
    interpreted in the order given on the command line.
  * Fixed issues with raising the Qt Creator window on Gnome desktop
    (QTCREATORBUG-13845)
  * Fixed appearance on high DPI displays on Windows
    (QTCREATORBUG-11179)
  * Added locator filter for running external tools
  * For more details see:
    http://blog.qt.io/blog/2015/08/20/qt-creator-3-5-0-released/
* Wed Jun  3 2015 hrvoje.senjan@gmail.com
- Update to 3.4.1:
  * For more details see:
    http://blog.qt.io/blog/2015/06/02/qt-creator-3-4-1-released/
* Tue May 26 2015 herbert@graeber-clan.de
- BuildRequire libQt5WebKitWidgets-deve to make help pages show like Qt assistant
* Thu Apr 23 2015 hrvoje.senjan@gmail.com
- Update to 3.4 Final:
  * For more details see:
    https://blog.qt.io/blog/2015/04/23/qt-creator-3-4-0-released/
    and http://code.qt.io/cgit/qt-creator/qt-creator.git/plain/dist/changes-3.4.0?h=3.4
* Wed Apr  1 2015 hrvoje.senjan@gmail.com
- Update to 3.4. rc1:
  * For more details see:
    http://blog.qt.io/blog/2015/04/01/qt-creator-3-4-rc1-released/
* Mon Mar  9 2015 hrvoje.senjan@gmail.com
- Update to 3.4 beta1:
  * Added option to change environment for running external tools
    (QTCREATORBUG-4995)
  * Improved performance of output panes
  * Fixed that wizard windows were missing in Window menu
    (QTCREATORBUG-13766)
  * Switched to a QMimeDatabase based MIME database implementation
  * Added hint in empty editor area
  * Added "Copy Path and Line Number" to context menu of
    document selector
  * Added parenthesis highlighting to generic highlighter
  * Fixed that files with same file name but different path were
    not distinguishable in document selector and open documents pane
    (QTCREATORBUG-10185)
  * Fixed that symlinks and their target could be opened at
    the same time (QTCREATORBUG-5941)
  * Fixed that wrong highlight definition was downloaded when
    sorting the list in the settings
  * Fixed clean up of automatically registered documentation
  * Added handling of QMAKE_CXXFLAGS_(APP|SHLIB|PLUGIN) variables
  * Added option to put debug information in separate file
    (QTCREATORBUG-14009)
  * Fixed ANSI color support for application output
    (QTCREATORBUG-13764)
  * Fixed handling of DEFINES with escaped characters
  * Fixed that static libraries were deployed
  * Fixed finding source directory for build directory
  * Added option to show full command lines during build
  * Added Valgrind Memory Analyzer with GDB
  * Made it possible to search through event notes
    (QTCREATORBUG-13417)
  * Added support for binary literals (n3472)
  * Added locator filter for all included files
    (QTCREATORBUG-280)
  * Added refactoring action that moves all function
    definitions out of a class declaration
  * Added support for signal and slot completion
    in Qt 5 style connects
  * Improved support for non-Qt projects that use Qt keywords
  * Made auto-completion delay configurable
    (QTCREATORBUG-13393)
  * Fixed auto-indentation for break in switch statement
    (QTCREATORBUG-13155)
  * Fixed issues with case-insensitive file systems
    (QTCREATORBUG-12390)
  * Fixed completion for enums inside member functions
    (QTCREATORBUG-13757)
  * Fixed crash on closing one of multiple outline views
    (QTCREATORBUG-13614)
  * Fixed that Move Definition to Class refactoring action was
    not available when using "override" (QTCREATORBUG-13564)
  * Fixed that Assign to Local Variable refactoring action was
    not working with chained function calls (QTCREATORBUG-10355)
  * Fixed several issues with completion and iterators
    (QTCREATORBUG-13799)
  * Fixed crash on closing one of multiple outline views
    (QTCREATORBUG-13614)
  * Added support for "git stash --keep-index" (QTCREATORBUG-13587)
  * Fixed that it was not possible to abort query and fetch
    (QTCREATORBUG-9743)
  * Fixed that not all remotes where shown in Push to Gerrit dialog
    (QTCREATORBUG-13718)
  * Added option to show verbose log
  * Changed to use the new unified diff viewer
  * Fixed that committing failed when using non-Latin1 characters in
    commit message (QTCREATORBUG-13979)
  * Improved repository log (QTCREATORBUG-13526)
  * Fixed target column for various commands
  * Fixed behavior of "D" in visual block mode
  * Fixed cursor shape after failing search
  * Fixed issues with pasting in presence of splits
    (QTCREATORBUG-13481)
  * Added support for 64bit tool chains
  * Fixed that active run configuration setting was ignored
    for deploying application
    (QTCREATORBUG-13732)
  * Added optional host key checking (QTCREATORBUG-13339)
  * Added automatic closing of SSH connections after a
    period of inactivity
  * Added support for SHA-256 HMAC for SSH
  * Fixed that it was not possible to quote run arguments
    (QTCREATORBUG-14002)
  * Added GDB server configuration management (QTCREATORBUG-13686)
  * Added support for remote channel without port
  * Added support for generic projects
- Drop make-qt-creator-build-with-Werror=date-time.patch, merged
  upstream
* Thu Feb 26 2015 hrvoje.senjan@gmail.com
- Update to 3.3.1:
  * For more details please see:
    http://blog.qt.io/blog/2015/02/24/qt-creator-3-3-1-released/
    and https://qt.gitorious.org/qt-creator/qt-creator/source/3.3:dist/changes-3.3.1
* Tue Feb  3 2015 hrvoje.senjan@gmail.com
- Add make-qt-creator-build-with-Werror=date-time.patch:
  don't embedded date & time into qtcreator binary & plugins
- Extend rpmlintrc file to avoid duplicates warnings, we don't wont
  to use fdupes due to unpredictable symlinking
* Wed Dec 10 2014 hrvoje.senjan@gmail.com
- Update to 3.3 Final
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/12/10/qt-creator-3-3-0-released/
    and https://qt.gitorious.org/qt-creator/qt-creator/source/3.3:dist/changes-3.3.0
- Raise required Qt5 version to 5.4.0
* Thu Nov 27 2014 hrvoje.senjan@gmail.com
- Update to 3.3.0 RC1
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/11/27/qt-creator-3-3-rc-released/
    and https://qt.gitorious.org/qt-creator/qt-creator/source/3.3:dist/changes-3.3.0
* Tue Oct 21 2014 hrvoje.senjan@gmail.com
- Update to 3.2.2
  * Bugfix release
  * Editing
  * Fixed crash with Toggle Comment Selection
    (QTCREATORBUG-12987)
  * Fixed that Select All set the cursor to top of document
    (QTCREATORBUG-12860)
  * Help
  * Fixed crash with help index locator filter
  * Managing and Building Projects
  * Fixed that closing Qt Creator while Projects mode
    is active lost all session data (QTCREATORBUG-13098)
  * CMake Projects
  * Fixed crash when selecting make target
    (QTCREATORBUG-13129)
  * Generic Projects
  * Fixed that include paths were not updated when
    files are added (QTCREATORBUG-12873)
  * Version Control Systems
  * ClearCase
  * Fixed that reserved checkout was performed even when
    unchecking the checkbox (QTCREATORBUG-12847)
- Added explicit libQt5Sql5-sqlite BuildRequires
* Thu Sep 25 2014 infroma@gmail.com
- Explicitly require latest libQt5Script5 (needed by plugins).
  Qt Creator crashes with old versions.
* Tue Sep 16 2014 hrvoje.senjan@gmail.com
- Update to 3.2.1
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/09/16/qt-creator-3-2-1-released/
* Tue Aug 19 2014 hrvoje.senjan@gmail.com
- Update to 3.2.0
  * Block selections in text editors now allow you to do “column
    editing”, meaning that all selected lines are edited
    simultaneously (Qt Creator Manual)
  * Context help can now be configured to open in an external
    window (without disabling Help mode)
  * Support for C99 designated initializers and concatenated strings
    was added to the C++ code model, as well as improvements to
    encoding handling and lambda  support and many other things
  * More panes are now searchable with Ctrl+F, for example the
    project tree
  * The QML profiler received many performance and stability
    improvements again
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/08/19/qt-creator-3-2-0-released/
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Update to 3.1.2
  * Bugfix release, for more details please see:
    http://blog.qt.digia.com/blog/2014/06/25/qt-5-3-1-released/
* Tue May 20 2014 hrvoje.senjan@gmail.com
- Update to 3.1.1
  - General
  * Fixed editing of MIME types while filtering is applied
    (QTCREATORBUG-12149)
  - Managing and Building Projects
  * Fixed performance regression in Issues pane (QTCREATORBUG-12109)
  - Qbs Projects
  * Fixed support for VS2013 compiler (QTCREATORBUG-11025)
  - C++ Support
  * Fixed issue with missing semantic highlighting (QTCREATORBUG-11367)
  - Qt Quick Designer
  * Fixed several UI issues (QTCREATORBUG-12040, QTCREATORBUG-12035,
    QTCREATORBUG-11904, QTCREATORBUG-12018)
  * Fixed anchor and alignment handling (QTCREATORBUG-12006)
  - Diff Viewer
  * Fixed crash when showing binary file containing carriage return
    character (QTCREATORBUG-12056)
  - Version Control Systems
  * Git
  * Fixed encoding issues on Window
  * Fixed crash when closing Qt Creator after revert
    (QTCREATORBUG-12099)
* Wed Apr 16 2014 hrvoje.senjan@gmail.com
- Update to 3.1.0 final
  * For full changelog see:
    https://qt.gitorious.org/qt-creator/qt-creator/source/3.1:dist/changes-3.1.0
* Wed Apr  2 2014 hrvoje.senjan@gmail.com
- Update to 3.1.0 rc1
  * For more details see:
    http://blog.qt.digia.com/blog/2014/04/03/qt-creator-3-1-rc1-released/
- Only enable clang plugins on arches where clang is available
- Move the creator back to standard location
- Added conflict with Qt4 version
- Drop plugin_path.diff
- Build qbs plugin
- Added qbs-path.diff (imported from Qt4 version), so qbs plugin gets
  installed to correct location
- Removed unused, and not needed sed workarounds from spec
- Improve logic for required libQt5Designer package
* Mon Mar 24 2014 hrvoje.senjan@gmail.com
- Update to 3.1.0 beta
  * Experimental support for a Clang-based C++ model
  * Droped support for GDBs that do not support scripting through Python
  * For more details, please see:
  https://blog.qt.digia.com/blog/2014/03/04/qt-creator-3-1-beta-released/
  and https://qt.gitorious.org/qt-creator/qt-creator/source/3.1:dist/changes-3.1.0
- Used sed in %%prep step, to swap destination if buildoutputparser binary,
  so it installs to correct location
- Activate clangmodel plugin, by BuildRequiring llvm-clang-devel and
  passing LLVM_INSTALL_DIR to qmake
- Bump minimal Qt5 version to 5.3.0 beta
* Wed Feb  5 2014 hrvoje.senjan@gmail.com
- Update to 3.0.1:
  * For more details please see:
    http://blog.qt.digia.com/blog/2014/02/05/qt-creator-3-0-1-released/
- Build with system Botan library, accomplished by passing
  USE_SYSTEM_BOTAN=1 to qmake. Thus added libbotan-devel BuildRequires
* Mon Dec 16 2013 hrvoje.senjan@gmail.com
- Move away from pkgconfig(...) BuildRequires and just use
  libqt5-$upstreammodulename-(devel|private-headers-devel)
* Fri Dec 13 2013 hrvoje.senjan@gmail.com
- Update to 3.0.0 final
- See http://blog.qt.digia.com/blog/2013/12/12/qt-creator-3-0-released/
- For the complete changelog see:
  http://qt.gitorious.org/qt-creator/qt-creator/blobs/3.0/dist/changes-3.0.0
* Fri Nov 29 2013 hrvoje.senjan@gmail.com
- Update to 3.0.0 rc1
  * New feature release, please see
  http://blog.qt.digia.com/blog/2013/11/29/qt-creator-3-0-rc1-released/
  and https://qt.gitorious.org/qt-creator/qt-creator/source/3.0:dist/changes-3.0.0
- Due to qtcreators buildsystem, and it's usage of private headers,
  BuildRequire latest Qt5 version, so it always rebuilds against it
- Require exact libQt5Designer5 version creator was built against, so
  the above change makes more sense
* Thu Oct 24 2013 hrvoje.senjan@gmail.com
- Update to 3.0.0 beta
  * New feature release, please see
    http://blog.qt.digia.com/blog/2013/10/23/qt-creator-3-0-beta-released/
- Package can now co-exist with qt-creator (based on Qt4) package
- Added plugin_path.diff to enable co-existance of the two packages.
  Patch removes hardcoded plugin path, and adjusts qtcreator recognizing
  plugin path as per install prefix
* Wed Oct  9 2013 hrvoje.senjan@gmail.com
- Manually install desktop file. Also added mimetypes, to emulate
  Qt4 creator behaviour
* Sun Oct  6 2013 hrvoje.senjan@gmail.com
- Added pkgconfig(Qt5X11Extras) BuildRequires, it is needed for
  raising the main window
* Fri Sep 13 2013 hrvoje.senjan@gmail.com
- Update to 2.8.1:
  * Bugfix release, please see
    http://qt.gitorious.org/qt-creator/qt-creator/blobs/2.8/dist/changes-2.8.1
- Add Source URL
* Thu Sep  5 2013 cfarrell@suse.com
- license update: SUSE-LGPL-2.1-with-digia-exception-1.1
  See spreadsheet linked from license.opensuse.org
* Tue Jul 16 2013 binner@kde.org
- disable qbs plugin for now
* Thu Jul 11 2013 stephan.binner@basyskom.com
- Update to 2.8
* Sun Jul  7 2013 stephan.binner@basyskom.com
- Update to 2.8 RC
* Thu May 30 2013 stephan.binner@basyskom.com
- Update to 2.8 Beta
* Wed May 15 2013 stephan.binner@basyskom.com
- Update to 2.7.1
* Thu Mar 21 2013 stephan.binner@basyskom.com
- Update to 2.7 Final
* Thu Mar  7 2013 stephan.binner@basyskom.com
- Update to 2.7 RC
* Thu Jan 31 2013 stephan.binner@basyskom.com
- Update to 2.6.2 release
* Thu Dec 20 2012 stephan.binner@basyskom.com
- Update to 2.6.1 release
* Mon Nov 12 2012 stephan.binner@basyskom.com
- Update to 2.6 release
* Wed Oct 17 2012 stephan.binner@basyskom.com
- Update to 2.6 RC
* Mon Sep 24 2012 stephan.binner@basyskom.com
- Update to 2.6 Beta
* Sat May 12 2012 stephan.binner@basyskom.com
- Update to 2.5 Release
* Mon Apr 23 2012 stephan.binner@basyskom.com
- Update to 2.5 Release Candidate
* Fri Mar 16 2012 stephan.binner@basyskom.com
- Update to 2.5 beta release
* Wed Feb  1 2012 stephan.binner@basyskom.com
- Update to 2.4.1 release
* Tue Dec 13 2011 stephan.binner@basyskom.com
- Update to 2.4 release
* Wed Nov 16 2011 stephan.binner@basyskom.com
- Update to 2.4 RC
* Fri Sep 30 2011 stephan.binner@basyskom.com
- Update to 2.3.1 release
* Thu Sep  1 2011 stephan.binner@basyskom.com
- Update to 2.3 release
* Mon Aug 22 2011 stephan.binner@basyskom.com
- Update to 2.3 Release Candidate
* Tue Jun 21 2011 stephan.binner@basyskom.com
- Update to 2.2.1 release
* Fri May  6 2011 stephan.binner@basyskom.com
- Update to 2.2 release
* Wed Apr 20 2011 wstephenson@novell.com
- Enable QML Designer build.  Disable it in Help->Plugins... if it
  causes problems.
* Tue Apr 19 2011 wstephenson@novell.com
- Update to 2.2.0rc1
  * Fixes for ABI detection
  * Fixes to QML debugging
  * Fixes to syntax highlighting
  * Fixes to Maemo development
* Mon Apr  4 2011 javier@opensuse.org
- Add Recommends: libqt4-devel-doc
* Thu Mar 24 2011 cgiboudeaux@gmx.com
- Update to 2.2.0beta1
  General
  * Added support for running user defined external tools (Tools->External)
  * Moved toolchain definitions out of Qt versions.
  * You can now define toolchains in Tools->Options->ToolChains
  * Creator now supports more than one instance of each kind of toolchain
  * Support for MIME type customization through editing of patterns and
    magic matchers.
  Editing
  * Add new Inkpot color scheme
  * Moved 'Open in External Editor' to Tools->External->Text
  * Add UTF-8 BOM support
  * GLSL Support with:
  - syntax checking
  - highlighting
  - code completion
  * Add 'expand/collapse all' context menu entry to Outline pane
  * Support for user defined macros was contributed by Nicolas Arnaud-Cormos
  * Snippet editor with syntax highlighting, indentation, and basic auto
    completion for C++ and QML.
  Project Support
  * QMake project support should be more robust against syntax errors
  * Treatment of command line arguments of processes started from build
    and run configurations underwent heavy modifications:
  - argument lists use native shell syntax; this affects quoting and
    environment variable expansion most
  - the SOURCEDIR and BUILDDIR environment variables were replaced
    with %%{sourceDir} and %%{buildDir} macros
  - this affects working directories and executable paths as well
  * CMake: Add Ui completion, changes in .ui files are picked up without
    a rebuild.
  * Syntax highlighting and completion for QMake project files
  * Text editor behavior settings now avaiable on a per-project basis.
  Debugging
  * Rewrote debugging engine using the Microsoft Console Debugger (CDB)
    for debugging executables built with Microsoft Visual Studio,
    resulting in significant speed-up and better display of data
    types, supporting both 32bit and 64bit versions of the
    Debugging Tools for Windows
  * Made it possible to pin debugger tooltips.
  * Reworked global architecture to allow multiple debugging sessions (for
    different projects, combined Qml/C++ debugging, project 'snapshots', ...)
  * Reworked breakpoint handling: new special breakpoint types for "break
    on throw", "break on main", data breakpoints
  * Introduce combined c++/qml debugging (combined stack, cross-step) (gdb only)
  * Rework per-type and per-item selection of display formats
  * New dumpers for QTextCursor, QTextDocument, __m128, QScriptValue
    QBasicAtomicPointer, bit fields, boost::shared_ptr (gdb only)
  * Improve dumpers for QRegion, QVariant (custom types), QSharedPointer,
    QMultiMap (QTCREATORBUG-3122), QObject, QWeakPointer
  * Make alphabetic structure member sorting optional
  * Make dumpers robust in case of missing debug information
  * Improve python dumper profiling support
  * Improve stepping performance
  * Enable breakpoint setting from a disassembler view, QTCREATORBUG-3667
  * Fix display of shadowed variables.
  * Fix display of data containing quote characters, QTCREATORBUG-3084
  * Fix display of C style 'typedef struct X { ... } X;
  * Fix stack/break view updates after manual module loading, QTCREATORBUG-3427
  * Fix 'Jump To/Run to' when in instruction-wise mode
  * Several fixed to the "watcher" handling
  * Allow re-running debugger engines, QTCREATORBUG-3073
  * Robust process control after -exec-interrupt errors, QTCREATORBUG-2850
  * Robust detection of Qt-in-namespace builds
  * Handle "live updates" in the memory view
  * Make memory view writable (gdb only)
  * Improve starting debugger session directly from the command line
  * Improve debugging helpers dialog
  BinEditor:
  * Visualize data differences after updates
  * Fix selection if cursor is left of anchor
  * Allow copying also if selection is "backwards"
  * Do not draw blinking cursor when there is a selection
  C++ Support
  * Add QuickFix for implementing setters/getters for a Q_PROPERTY
  * Add documentation about QuickFixes
  * Fix switch statement indentation for GNU and Whitesmiths
    style, QTCREATORBUG-2994
  * Fix indentation of labels
  * Highlighting for virtual functions
  * Navigate to correct overloaded function/method
  QML/JS Support
  * Add wizard for creating JavaScript files, QTCREATORBUG-3070
  * Add local-file completion for url properties, QTCREATORBUG-2619
  * Add warning about invalid files in url properties
  * Add file name completion in imports, QTCREATORBUG-3067
  * Add a locator filter for JS functions, QTCREATORBUG-2607
  * Add JSlint-style warnings about common JS pitfalls, QTCREATORBUG-3071
  * Add completion for attached properties like Component.onCompleted
  * Allow QML modules to ship predumped type description files.
  * Reenable instantiating component scope detection, QTCREATORBUG-2835
  * Improve error reporting of failed plugin dumps
  * Complete a trailing '{' for 'A on b' object bindings, QTCREATORBUG-2642
  * Highlight capitalized types, QTCREATORBUG-2658
  * Re-dump a plugin if the shared library/dll changes, QTCREATORBUG-3047
  * Build qmldump in debug and release version on Windows, QTCREATORBUG-3549
  * Change qmldump to output QML instead of XML
  * Fix automatic '.' import to also pick up QML modules, QTCREATORBUG-3768
  * Fix code model update when files are renamed, QTCREATORBUG-2986
  * Fix incorrect completion when brace is on separate line, QTCREATORBUG-2658
  * Fix quote autoinsertion in string literals, QTCREATORBUG-2155, QTCREATORBUG-3244
  * Fix '{' not being an electric character, QTCREATORBUG-3405
  * Fix indentation of 'foo: Namesp.Type {', QTCREATORBUG-3371
  * .qmlproject format: Allow specifying the 'mainFile' qml file, bump version to 1.1
  * Qt Quick UI project: allow user to change run environment
  QML/JS Debugging:
  * Compile qmljsdebugger code as static library, and link it based on checkbox in qmake step
    (replaces QMLJSDEBUGGER_PATH / QMLJSDEBUGGER define)
  * Qt Quick Application: Allow debugging also in release builds, improve error diagnostics
  * Gui cosmetics in JS debugger: Show stack frame level, only valid
    line numbers in stack view, do not show function code, show dummy
    child entry for empty arrays
  * Added qml tooltips for property inspection at debug time
  * Extended QML Observer for inspection and tweaking of item's properties
  * Added navigation of the object tree in the QML Observer through a crumble path
  * Add 'show app on top' option
  * Move toolbar from Observer tab to the main toolbar space
  * Support setting of breakpoints in .qml files embedded as qrc resources
  * Improve 'linkification' of QML errors in Application Output pane
  FakeVim:
  * Implement Ctrl-N/Ctrl-P
  * Implement 's' in visual block mode
  * Fix Alt-Gr handling on Windows
  * Handle more Ctrl-W + <x> commands
  Symbian Target
  * Added support for the new on-device debugging agent (CODA)
  Version control plugins
  * Bazaar support was contributed by Hugues Delorme
  Wizards
  * Support new keywords %%MONTH%% and %%DAY%% for C++ template file
  Misc
  * MemCheck (from Valgrind) integration (Linux, Mac)
  * Create infrastructure to setup "soft dependencies" between plugins
  * Add a little tool 'qtpromaker' doing the job of 'qmake -project', but
    much faster to make Qt Creator usable to quickly inspect and navigate
    "alien" codebases a way to easily set up dummy .pro files is needed
  * Start documenting Qt Creator's coding style guidelines
  [etc]
* Tue Mar  1 2011 cgiboudeaux@gmx.com
- Update to 2.1.0
  * Semantic C++ highlighting: Highlighting of types, local variables vs members, virtual methods
  * Generic highlighting adds highlighting for various file types based on the Kate highlight definition specification
  * C++ class view and image viewer contributed by Denis Mingulov
  * Outline views for C++ and QML
  * Searching for C++ symbols matching a pattern (via advanced find dialog)
  * Wizard for adding libraries to pro files, including all the necessary fancy magic for include paths and static libs
  * Various debugging improvements on all platforms
  * Improved QML code editing with a faster code model and a new indenter
  * Find usages and improved follow symbols in QML code
  * Graphical QML tool bar for setting e.g. fonts and colors in the QML code editor
  * Project wizards for Qt Quick applications that also handle deployment to devices, and for custom QML extension plugins
  * Mobile application project wizards that provide you with the needed setup for Symbian and Maemo, and packaging and deployment
  * Various improvements to deployment to Maemo targets and Symbian support
  * Click on QObject::connect warnings in application output to jump to the code
* Tue Dec  7 2010 cgiboudeaux@gmail.com
- Update to 2.1rc1
  * Many small bugfixes since beta2, see
    http://chaos.troll.no/~dmolkent/qt-creator-changelog-rc1.txt
    for details
  * Updated Russian and Polish translations
* Sat Nov 20 2010 dmueller@suse.de
- update to 2.1.0beta2:
  * Made search result panel searchable
  * Generic highlighter:
    http://labs.qt.nokia.com/2010/09/16/generic-highlighter-in-qt-creator/
  * Added semantic highlighting of types, virtual methods, locals, statics and
    member variables (only enabled when running against Qt 4.7.1 and up, for
    performance reasons)
  * Add new indenter along with a new option to control alignment indents
  * Add new %%FILENAME%%, %%CLASS%% placeholders to license template
  * Added searching for symbols that match a pattern to advanced find
  * Made 'Follow symbol' for classes skip forward declarations
  * Added option for adding subprojects to projects in the New wizard
  * Added context-menu command for removing subprojects in the Edit mode,
    Projects view
  * Added a wizard for adding other than Qt libraries to project files
  * Fixed splitter inconsistency of debugger tool bar
  * Fixed console debugging with MinGW/gdb
  * Symbian: Added basic thread support, improve logging
  * New dumpers for QDate, QTime, QHostAddress, QRegion, boost::optional,
    QSharedData and QSharedDataPointer
  * Improved/fixed dumpers for QObject (include user defined properties), QList,
    C-style arrays, QSize, QSizeF, QImage/QPixmap, std::vector<bool>,
    QVariant(QString), qulonglong, std::size_t, std::ptrdiff_t,
    QScopedPointer, QStandardItem
  * Performance improvements due to use of dwarf index data to reduce gdb
    startup time, use of new gdb.read_memory for QByteArray and QString display
  * Debugger framework handles multiple debugging sessions in parallel
  * Allow per item and/or type selection of display method in Locals&Watchers
  * Implement data watchpoints
  * Implement a debugger engine to debug Python scripts
  * Direct remote debugging using -debug binary@host:port[@arch] on the command line
  * Make alphabetic sorting of struct members optional
  * New Add/Edit breakpoint dialog
  * Show QThread object names in threads view
  * Support for per-thread breakpoints
  * Show dynamic type of objects for gdb versions newer than Aug 31, 2010
  * [etc]
* Thu Sep  2 2010 dmueller@suse.de
- only use system botan for new-enough systems
* Mon Aug 30 2010 tittiatcoke@gmail.com
- update to 2.0.1
  see http://qt.nokia.com/developer/changes/changes-qtcreator-2.0.1
* Mon Aug 30 2010 dmueller@suse.de
- remove botan copy, use system version instead
- fix runpath (bnc#613978)
* Mon Jun 21 2010 dmueller@suse.de
- fix gdb version checks (bnc#615361)
* Tue Jan 26 2010 wstephenson@novell.com
- update to 1.3.1:
  General:
  * Updated translations
  Editing:
  * Fixed drawing issues when line wrap is enabled
  * Fixed problem with indentation when auto-indent is turned off
  C++ support:
  * Don't show the refactoring warning message all the time
  * Insert semicolon when matching enum declarations
  * Fixed function argument widget text color in dark themes
  * Fixed that inline implemented methods did not show up in the
    methods filter
  * Fixed in-place renaming when text is selected
  * Fixed autoindent when using tabs instead of spaces
  * Fixed completion when a typedef symbol is used as class name
  * Fixed that template argument was marked as "not a type name" when
    defined as primitive type
  * Fixed some highlight errors in code using the win32 API
  * Improved completion of function definition parameter lists to
    append the const and volatile qualifiers if required
  Project support:
  * Fixed that run configurations were disabled if they had no
    build step
  Debugging:
  * CDB: Fixed disassembler for 64 bit addresses
  * Fixed finding the file for build issues when mingw32-make is used
  * Ignore case of file name in breakpoint handling on Windows
  * Fixed problems with gdb timing out and debugging sessions
    unexpectedly finishing
  * Improved startup time of gdb sessions by not asking for all
    files known to gdb
  Help:
  * Don't switch to Help mode if help side bar is already visible
  Symbian Target:
  * Fixed the time stamp of deployed files
* Sat Jan  2 2010 dmueller@suse.de
- update to 1.3.0 final:
  * only bugfixes compared to previous version update
* Sat Nov 21 2009 binner@kde.org
- update to 1.3 release candidate:
  * Preliminary support for Qt development targeting Symbian platform
  * New support for source code refactoring
* Tue Sep 29 2009 dmueller@suse.de
- require the Qt version it was built against (bnc#542775)
* Wed Aug  5 2009 beineri@opensuse.org
- install bin/qt-creator wrapper (bnc#526768)
* Thu Jul 16 2009 dmueller@novell.com
- update to 1.2.1:
  * http://www.qtsoftware.com/developer/changes/changes-qtcreator-1.2.1
* Sun Jun 28 2009 binner@kde.org
- update to 1.2 release:
  * The Welcome Screen has been redesigned
  * There has been some speed improvements: large amounts of
    persistent data now stored in an SQLite database
  * Added a block highlighting feature
  * Improved the code folding markers
  * FakeVim mode has received further improvements
  * Added the option to auto-save before building
  * Made auto-build before run optional
  * Made it possible to disable breakpoints
* Thu Apr 23 2009 beineri@opensuse.org
- update to 1.1 release:
  * Completely reworked editor split mechanism
  * Improved function argument hint
  * Improved open documents view (sorted, single-click, close buttons)
  * Added experimental support for generic Makefile based projects
  * Added signal/slot editor to the form editor
* Mon Mar 30 2009 dmueller@suse.de
- merge with Factory
* Fri Mar 20 2009 Nico Kruber <Nico.Laus.2001@gmx.de>
- fixed designer and resource editor plugin not being built
  - added .desktop file
* Wed Mar  4 2009 dmueller@suse.de
- merge with Factory
* Tue Mar  3 2009 beineri@opensuse.org
- update to 1.0 release
  * no changelog available
* Fri Feb 27 2009 dmueller@suse.de
- remove doc stuff as it doesn't build currently
* Wed Feb 18 2009 stbinner@suse.de
- update to 0.9.2rc1
* Tue Dec 30 2008 stbinner@suse.de
- initial package of version 0.9.1-beta
